import isNumberEmpty from './isNumberEmpty'

/**
 * 通过字节转换为相应的size
 * 用法： bytesToSize(1024) => "1 KB"
 * @param bytes {number}
 * @returns {string}
 */
function bytesFormatSize(bytes) {
	if (isNumberEmpty(bytes)) return '0 B'

	let k = 1024
	let sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB']
	let i = Math.floor(Math.log(bytes) / Math.log(k))
	let number = (bytes / Math.pow(k, i)).toPrecision(3)
	let size = sizes[i]
	return scientificToNumber(number) + ' ' + size
}

// 处理科学计数法特殊数值
function scientificToNumber(num) {
	if (/\d+\.?\d*e[\+\-]*\d+/i.test(num)) {
		let zero = '0'
		let parts = String(num).toLowerCase().split('e')
		let e = parts[1]
		let zeroLen = Math.abs(e)
		let sign = e / zeroLen
		let beforeArr = parts[0].split('.')
		if (sign < 0) {
			num = zero + '.' + new Array(zeroLen).join(zero) + beforeArr.join('')
		} else {
			let dec = beforeArr[1]
			if (dec) {
				zeroLen = zeroLen - dec.length
				num = beforeArr.join('') + new Array(zeroLen + 1).join(zero)
			}
		}
	}
	return num
}

export default bytesFormatSize
