/**
 * @author kai
 * @date  2022-11-11
 * @description 校正windows页面在系统进行缩放后导致页面被放大的问题，通常放大比例是125%、150%
 * 但目前缩放存在像素布局的问题，之前用像素写的布局在缩放后会变得奇怪，所以慎用。
 * **/
function correctZoomRatio() {
    var agent = navigator.userAgent.toLowerCase();
    //现只针对windows处理，其它系统暂无该情况，如有，继续在此添加
    if (agent.indexOf("windows") >= 0) {
        //初始化页面校正浏览器缩放比例
        _correct();
        //开启监听页面缩放
        _watch();
    }
}

//监听方法兼容写法
function _addHandler(element, type, handler) {
    if (element.addEventListener) {
        element.addEventListener(type, handler, false);
    } else if (element.attachEvent) {
        element.attachEvent("on" + type, handler);
    } else {
        element["on" + type] = handler;
    }
}

//校正浏览器缩放比例
function _correct() {
    //页面设备像素比例变化后，计算页面body标签zoom修改其大小，来抵消devicePixelRatio带来的变化。
    document.getElementsByTagName('body')[0].style.zoom = 1 / window.devicePixelRatio;
}

//监听页面缩放
function _watch() {
    _addHandler(window, 'resize', function () { //注意这个方法是解决全局有两个window.resize
        //重新校正
        _correct()
    })
}

export default correctZoomRatio;
