/**
 * 根据func删除满足树形结构的节点，你可以理解为filterTree的取反。
 * @param tree {array} 树形数据
 * @param func {function} 条件函数
 * @param children {string} children的属性名
 * @returns {BigInt64Array} 删除节点后的树结构数据
 */
function deleteTree(tree, func, children = 'children') {
    try {
        // 使用map复制一下节点，避免修改到原树
        let newData = tree
            .map((node) => ({...node}))
            .filter(node => {
                return func(node)
            })
        newData.forEach(node => node[children] && (node[children] = deleteTree(node[children], func, children)))
        return newData
    } catch (e) {
        console.error('deleteTree.js [easy-project-vue error]:', e)
        return []
    }
}

export default deleteTree
