import isStringEmpty from "./isStringEmpty";
import findFileName from "./findFileName";

/**
 *
 * 下载
 * @param  {String} url 目标文件地址
 * @param  {String} fileName 想要保存的文件名称，最好带上文件后缀（非必填）
 * @returns {Promise<void>}
 */
async function downloadFile(url, fileName = undefined) {
    if (isStringEmpty(url)) {
        return Promise.reject('url丢失！')
    }

    let response = await fetch(url).catch((error) => {
        return Promise.reject(error)
    }) // 内容转变成blob地址
    let blob = await response.blob() // 创建隐藏的可下载链接
    let link = document.createElement('a')
    link.style.display = 'none'
    link.href = window.URL.createObjectURL(blob)
    if (isStringEmpty(fileName)) {
        // 没有传name，就用url的文件名
        fileName = findFileName(url)
    }
    link.setAttribute('download', fileName)
    document.body.appendChild(link)
    link.click()
    document.body.removeChild(link) // 下载完成移除元素
    window.URL.revokeObjectURL(url) // 释放掉blob对象
    return Promise.resolve()
}


export default downloadFile
