/**
 * 根据func(函数)搜索查找树结构的节点，常用于模糊查询树节点，返回值会保持原有的结构。
 * 树结构过滤即保留某些符合条件的节点，剪裁掉其它节点。
 * 一个节点是否保留在过滤后的树结构中，取决于它以>及后代节点中是否有符合条件的节点。可以传入一个函数描述符合条件的节点:
 * @param tree {array} 树形数据
 * @param func {function} 筛选函数
 * @param children {string} children的属性名
 * @returns {*[]|*}
 */
function filterTree(tree, func, children = 'children') {
    try {
        // 使用map复制一下节点，避免修改到原树
        return tree
            .map((node) => ({...node}))
            .filter((node) => {
                node[children] = node[children] && filterTree(node[children], func);
                return func(node) || (node[children] && node[children].length);
            });
    } catch (e) {
        console.error('filterTree.js [easy-project-vue error]:', e)
        return []
    }
}


export default filterTree
