/**
 * 查找出第一个满足条件的树节点，未查到则返回null
 * @param tree {array} 树形数据
 * @param func {function} 筛选函数 返回true或false
 * @returns {any|null}
 * 用法：let firstDeepMenu = findTree(treeData, node => !node.hidden)
 */
import isArrayEmpty from "./isArrayEmpty";

function findTree(tree, func, children = 'children') {
    try {
        if (isArrayEmpty(tree)) {
            return null
        }

        for (const data of tree) {
            if (func(data)) return data
            if (data[children]) {
                const res = findTree(data[children], func, children)
                if (res) return res
            }
        }
        return null
    } catch (e) {
        console.error('findTree.js [easy-project-vue warn]:', e)
        return null;
    }
}

export default findTree
