import isArrayEmpty from "./isArrayEmpty";
import deepClone from "./deepClone";

/**
 * @description: 获取树形结构的每一个节点的最后一个子节点
 * @param tree {array} 树形数据
 * @param func {function}  可选 筛选条件函数，填了会过滤掉不符合条件的节点，不填就直接获取最后一个节点。
 * @param children {string} children的属性名
 * @return lastChildren {array} 每一个节点的最后一个子节点数组
 * @author: hekai
 */
function findTreeDeep(tree, func, children = 'children') {
    if (isArrayEmpty(tree)) {
        return []
    }

    function getFirstDeepChildren(treeNode, func) {
        let result = []

        function each(node, firstDeepNode) {
            if (node[children] && node[children].length !== 0) {
                if (func) {
                    // 去掉不符合筛选条件的node
                    node[children] = node[children].filter((item) => {
                        return func(item)
                    })
                }
                each(node[children][0], firstDeepNode)
            }
            result.push(node)
        }

        each(treeNode, result)
        return result[0]
    }

    try {
        let lastChildren = []
        // 对源数据深度克隆
        const cloneData = deepClone(tree)
        for (let i = 0; i < cloneData.length; i++) {
            let node = cloneData[i]
            lastChildren.push(getFirstDeepChildren(node, func))
        }
        return lastChildren
    } catch (e) {
        console.error('findTreeDeep.js [easy-project-vue error]:', e)
        return []
    }
}


export default findTreeDeep
