import isArrayEmpty from "./isArrayEmpty";

/**
 * @description: 获取传入子节点参数的id，查到此节点，并获取层级数据
 * @param {array} tree 树形数据
 * @param {function} func 查找依据的函数
 * @param {string} children children的属性名
 * @param {array} path 初始值
 * @return {array} 数组 [1级-2级-3级-4级-5级]
 * @author: hekai
 */
function findTreePath(tree, func, children = 'children', path = []) {
    try {
        if (isArrayEmpty(tree)) return []; //空判断

        for (const data of tree) {
            path.push(data);
            if (func(data)) return path;
            if (data[children]) {
                const findChildren = findTreePath(data[children], func, children, path);
                if (findChildren.length) return findChildren;
            }
            path.pop();
        }
        return [];
    } catch (e) {
        console.error('findTreePath.js [easy-project-vue warn]:', e)
        return [];
    }
}


export default findTreePath
