/**
 * @description: 根据对象数组的属性,生成该属性的值的重命名 (递归算法)
 * @param {array} arrData  对象数组
 * @param {string} attribute 依据的属性 如filedName
 * @param {*} name 要检测filedName中重复的值 例如“姓名”
 * @return {string} 返回重命名，比如‘姓名’字段重复两次，那么返回姓名(1)，以此类推，类似于windows文件系统的重命名处理。
 * 用法示例：getRepeatName(this.tableData, 'name', newName)
 * @author: hekai
 */
function getRepeatName(arrData, attribute, name) {
    let arr = JSON.parse(JSON.stringify(arrData))
    let repeatCount = _getRepeatCount(arr, attribute, name)

    if (repeatCount > 0) {
        let newName = _getName(repeatCount, name)
        return getRepeatName(arr, attribute, newName)
    }

    return name
}

/**
 * @description: 根据对象数组的属性,来获取该属性的值的重复次数
 * @param {*} arr 数组
 * @param {*} attribute 依据的属性
 * @param {*} value 重复的值
 * @return {*} 没有重复返回1，重复两次返回2，重复三次返回3，以此类推。
 * @author: hekai
 */
function _getRepeatCount(arr, attribute, value) {
    if (!Array.isArray(arr)) {
        console.log('type error!请检查是否是数组类型!')
        return
    }
    let count = 0
    arr.forEach(item => {
        if (item[attribute] === value) {
            count++
        }
    })
    return count
}

/**
 * 生成【名字(1)】格式的名称
 * @param repeatCount 重复次数
 * @param name 名字
 * @returns {string|*}
 */
function _getName(repeatCount, name) {
    // 用正则匹配小括号的数字
    let regex = /(?<=\()\d+(?=\))/
    let numList = name.match(regex)
    // 输出了一个数组，如果name已经是【名字(1)】的格式，那么名字生成为【名字(2)】
    if (numList && numList.length > 0) {
        let num = parseInt(numList[0])
        return name.replace(regex, num + 1)
    }
    return `${name}(${repeatCount})`
}

export default getRepeatName
