/**
 * 根据数组高亮搜索词，用法：v-html
 * <p v-html="highlightKeywords(’webpack详细的配置选项‘, ['webpack','配置'], '#008AFF')"></p>
 * <p v-html="highlightKeywords(’webpack详细的配置选项‘, 'webpack', '#008AFF')"></p>
 * @param val {string} 原始文本
 * @param keywords {string | array} 单个关键词字符串或字符串数组
 * @param color {string} 高亮颜色，默认值：'#008AFF'
 * @returns {string}
 */
import isStringEmpty from "./isStringEmpty";

function highlightKeywords(val, keywords, color = '#FF4441') {
    if (isStringEmpty(val)) {
        console.error('[easy-project-vue warn]:highlightKeywords方法的val必须是一个非空字符串！当前val:', val)
        return ''
    }


    try {
        let res = val
        if (keywords && keywords.constructor === String) {
            return res.replaceAll(keywords, `<span style="color:${color};">${keywords}</span>`)
        }

        if (keywords instanceof Array) {
            keywords.forEach(keyword => {
                if (val) {
                    res = res.replaceAll(keyword, `<span style="color:${color};">${keyword}</span>`)
                }
            })
            return res
        }
        return res
    } catch (e) {
        console.error('highlightKeywords.js [easy-project-vue error]:', e)
        return val
    }

}

export default highlightKeywords
