/**
 * 根据条件从树形结构中解析数据，返回数据为平级数组
 * 应用场景：在一堆的产品客户层级中，找到我们想要的类型的数据，返回的数据是平级的.
 * 这样可以使用表格或者其他来展示出我们想要看的结果。
 * @param tree {array} 树形数据
 * @param func {function} 筛选函数
 * @returns {array}
 */
function parseTree(tree, func) {
    try {
        return (tree || []).reduce((total, current) => {
            const {children, ...obj} = current;
            if (func(current)) {
                return total.concat(obj);
            }
            const parseChildren = parseTree(children, func);

            return total.concat(parseChildren);
        }, []);
    } catch (e) {
        console.error('parseTree.js [easy-project-vue error]:', e)
        return []
    }
}

export default parseTree
